A command line interface for watching RUV
=========================================

About
-----

A curses interface for watching and exploring available material from The
Icelandic National Broadcasting Service (RUV).

You can

* Explore featured material
* Browse the TV schedule
* Search for available material
* Watch live TV
* Listen to live radio

Installation
------------

Run

```
pip install ruv
```

and then `ruv --help`.
